@@ -97,6 +97,29 @@
 #' }
 "indicator_dataset"
 
+#' Table with price dataset, 30000 rows
+#'
+#' @docType data
+#' @keywords datasets
+#'
+#' @format A dataframe with several columns
+#' \describe{
+#'   \item{X1}{Date and time of the price sample}
+#'   \item{X2-X29}{Values of the assets}
+#' }
+"price_dataset_big"
+
+#' Table with indicator dataset, 30000 rows
+#'
+#' @docType data
+#' @keywords datasets
+#'
+#' @format A dataframe with several columns
+#' \describe{
+#'   \item{X1}{Date and time of the indicator sample}
+#'   \item{X2-X29}{Values of the assets}
+#' }
+"indicator_dataset_big"
 
 #' Table with one column indicator dataset
 #'
@@ -205,3 +228,54 @@
 #'
 #' }
 "DFR"
+
+#' Table with indicator and market type category used to train model
+#'
+#' @docType data
+#' @keywords datasets
+#'
+#' @format A dataframe with several columns
+#' \describe{
+#'   \item{X1-X128}{Values of the macd indicator}
+#'   \item{X129}{Category of Market Type}
+#' }
+"macd_ML2_small"
+
+#' Table with indicator only used to train model, 128 rows
+#'
+#' @docType data
+#' @keywords datasets
+#'
+#' @format A dataframe with several columns
+#' \describe{
+#'   \item{EURUSD}{Values of the macd indicator}
+#'   \item{GBPUSD}{Values of the macd indicator}
+#'   \item{AUDUSD}{Values of the macd indicator}
+#'   \item{NZDUSD}{Values of the macd indicator}
+#'   \item{USDCAD}{Values of the macd indicator}
+#'   \item{USDCHF}{Values of the macd indicator}
+#'   \item{USDJPY}{Values of the macd indicator}
+#'   \item{EURGBP}{Values of the macd indicator}
+#'   \item{EURJPY}{Values of the macd indicator}
+#'   \item{EURCHF}{Values of the macd indicator}
+#'   \item{EURNZD}{Values of the macd indicator}
+#'   \item{EURCAD}{Values of the macd indicator}
+#'   \item{EURAUD}{Values of the macd indicator}
+#'   \item{GBPAUD}{Values of the macd indicator}
+#'   \item{GBPCAD}{Values of the macd indicator}
+#'   \item{GBPCHF}{Values of the macd indicator}
+#'   \item{GBPJPY}{Values of the macd indicator}
+#'   \item{GBPNZD}{Values of the macd indicator}
+#'   \item{AUDCAD}{Values of the macd indicator}
+#'   \item{AUDCHF}{Values of the macd indicator}
+#'   \item{AUDJPY}{Values of the macd indicator}
+#'   \item{AUDNZD}{Values of the macd indicator}
+#'   \item{CADJPY}{Values of the macd indicator}
+#'   \item{CHFJPY}{Values of the macd indicator}
+#'   \item{NZDJPY}{Values of the macd indicator}
+#'   \item{NZDCAD}{Values of the macd indicator}
+#'   \item{NZDCHF}{Values of the macd indicator}
+#'   \item{CADCHF}{Values of the macd indicator}
+#'
+#' }
+"macd_100"
