@@ -67,21 +67,20 @@ evaluate_market_type <- function(x, model_path, num_cols){
 
 
   requireNamespace("h2o", quietly = TRUE)
-  requireNamespace("magrittr", quietly = TRUE)
 
   # load models
-  m1 <- h2o.loadModel(model_path)
+  m1 <- h2o::h2o.loadModel(model_path)
 
 
   if(class(m1)[1] == "H2ORegressionModel") {
   # Convert to matrix
-  X_m <- to_m(x, num_cols) %>% as.data.frame()
+  X_m <- lazytrade::to_m(x, num_cols) %>% as.data.frame()
   colnames(X_m) <- c(paste("X",1:num_cols,sep=""))
   # load the dataset to h2o
-  test  <- as.h2o(x = X_m, destination_frame = "test")
+  test  <- h2o::as.h2o(x = X_m, destination_frame = "test")
 
   # retrieve the predicted market type value
-  e1 <- h2o.predict(m1, test)
+  e1 <- h2o::h2o.predict(m1, test)
 
   # round the number to achieve class
   result <- round(e1) %>% as.vector()
@@ -97,15 +96,15 @@ evaluate_market_type <- function(x, model_path, num_cols){
   if(class(m1)[1] == "H2OMultinomialModel") {
 
     # Convert to matrix
-    X_m <- to_m(x, num_cols) %>% as.data.frame()
+    X_m <- lazytrade::to_m(x, num_cols) %>% as.data.frame()
     colnames(X_m) <- c(paste("X",1:num_cols,sep=""))
     X_m <- X_m %>% transform(M_T = "RAV")
 
     # load the dataset to h2o
-    test  <- as.h2o(x = X_m, destination_frame = "test")
+    test  <- h2o::as.h2o(x = X_m, destination_frame = "test")
 
     # retrieve the predicted value of the market type
-    e1 <- h2o.predict(m1, test) %>% as.data.frame()
+    e1 <- h2o::h2o.predict(m1, test) %>% as.data.frame()
 
     # output result of prediction from the function
     return(e1)
