@@ -28,7 +28,6 @@
 log_RL_progress <- function(x, states, actions, control){
   requireNamespace("dplyr", quietly = TRUE)
   requireNamespace("ReinforcementLearning", quietly = TRUE)
-  requireNamespace("magrittr", quietly = TRUE)
 
   # add dummy tupples with states and actions with minimal reward
   d_tupple <- data.frame(State = states,
@@ -37,7 +36,7 @@ log_RL_progress <- function(x, states, actions, control){
                          NextState = states,
                          stringsAsFactors = F)
   # generate RL model
-  model <- ReinforcementLearning(d_tupple, s = "State", a = "Action", r = "Reward",
+  model <- ReinforcementLearning::ReinforcementLearning(d_tupple, s = "State", a = "Action", r = "Reward",
                                  s_new = "NextState",iter = 1, control = control)
 
   # add rows of the x one by one to gradually update this model
@@ -47,7 +46,7 @@ log_RL_progress <- function(x, states, actions, control){
     State <- x[i-1,] %>% mutate(State = ifelse(Profit>0, "tradewin", ifelse(Profit<0, "tradeloss", NA))) %$% State
 
     # predict on i
-    Action <- computePolicy(model)[State]
+    Action <- ReinforcementLearning::computePolicy(model)[State]
 
     # reward
     Reward <- x[i,]$Profit
@@ -64,7 +63,7 @@ log_RL_progress <- function(x, states, actions, control){
     }
 
     # update model with new data tupple
-    model <- ReinforcementLearning(df_tupple, s = "State", a = "Action", r = "Reward",
+    model <- ReinforcementLearning::ReinforcementLearning(df_tupple, s = "State", a = "Action", r = "Reward",
                                    s_new = "NextState", control = control, iter = 1, model = model)
     #model$Q
 
